+++
title = "Sandpoints"
+++

# Sandpoints

Sandpoints is a publishing platform developed through rapid prototyping in the processes of collaborative writing projects such as PirateCare Syllabus, MachineLearning Curriculum or Dotawo - A Journal of Nubian Studies.

It allows for the development of collective writing and publishing projects under the conditions of modest or no access (e.g. Rojava) or in the work of vulnerable groups who require that their content never be accessible online. The full editing in the offline environment, with the ability to synchronize later in a P2P network or with a central server, is an essential aspect for such a scenario. But, also, Sandpoints allows readers to easily copy onto a USB drive a single folder containing the entire publication with the PDF collection of all references. Both the publication and the collection can then be viewed with an Internet browser, without the need to install any additional software.

Each Sandpoints instance has a three-tier, fuzzy hierachy of documents written in Markdown that can be named to correspond to technical or poetic exigencies of the publication being created. Triads can be: book > section > chapter, journal > issue > article, syllabus > topic > session, house > floor > room, ship > deck > compartment, or any other triad users might need. It also contains a library collection of electronic documents, articles and books that can be directly linked to and rendered as Chicago Manual of Style references in the documents written in Sandpoints.

Sandpoints runs on a [Gitea](https://gitea.io/en-us/) instance and is rendered using [Hugo](https://gohugo.io/).

<br><br>

## Technical details

- [Sandpoints repositories with short descriptions](https://git.sandpoints.org/Drawwell)
- [Documentation (old)](https://git.memoryoftheworld.org/PirateCare/Syllabus) — This is a very basic documentation, primarily demonstrating how to use the preview mode header shurtcuts to open documents for editing in Gitea's built-in editor.

<br>

## Sandpoints projects and communities

- [Public repositories](https://git.sandpoints.org/explore/repos) — Some of the repositories are not public and quite a few are either in a rudimentary stage or no longer maintained.

<br>

## Flagship projects

Out of those we want to highlight three projects to demonstrate a variety of prominent Sandpoints features.

<br>

### Dotawo - A Journal of Nubian Studies

#### About Dotawo

> Nubian studies needs a platform in which the old meets the new, in which archaeological, historical, and philological research into Meroitic, Old Nubian, Coptic, Greek, and Arabic sources confront current investigations in modern anthropology and ethnography, Nilo-Saharan linguistics, and critical and theoretical approaches present in postcolonial and African studies.

> The journal *Dotawo - A Journal of Nubian Studies* brings these disparate fields together within the same fold, opening a cross-cultural and diachronic field where divergent approaches meet on common soil. Dotawo gives a common home to the past, present, and future of one of the richest areas of research in African studies. It offers a crossroads where papyrus can meet internet, scribes meet critical thinkers, and the promises of growing nations meet the accomplishments of old kingdoms.

#### Prominent features

- [Issue 7](https://pages.sandpoints.org/dotawo/issue/dotawo7/)
- [Preview mode with header shortcuts to Gitea](https://pages.sandpoints.org/dotawo/_preview/journal/)
- [Issue 7 Print to PDF Page](https://pages.sandpoints.org/dotawo/print/issue7/) — In order to print, wait for the pagination to finish the count. Once finished, go to your browser's print feature to print to PDF.
- ![PDF](bib:b77f6255-c933-4d60-a221-585709c44776) as rendered via link to Print to PDF Page above
- [Structure of the Dotawo Sandpoints project](https://pages.sandpoints.org/dotawo/urls/)
- [Integrated library with all of the issue's references ain PDF](https://pages.sandpoints.org/dotawo/library/BROWSE_LIBRARY.html)
- [Bibliography example](https://pages.sandpoints.org/https://gohugo.io/dotawo/article/norton/#bibliography)

<br>

### Machine Listening, A Curriculum

#### About Machine Listening

> Our devices are listening to us. Previous generations of audio-technology transmitted, recorded or manipulated sound. Today our digital voice assistants, smart speakers and a growing range of related technologies are increasingly able to analyse and respond to it as well. Scientists and engineers increasingly refer to this as “machine listening”, though the first widespread use of the term was in computer music. Machine listening is much more than just a new scientific discipline or vein of technical innovation however. It is also an emergent field of knowledge-power, of data extraction and colonialism, of capital accumulation, automation and control. It demands critical and artistic attention.

> MACHINE LISTENING is a new investigation and experiment in collective learning, instigated by artist Sean Dockray, legal scholar James Parker, and curator Joel Stern for Liquid Architecture and launched at Unsound 2020: Intermission. It comes out of our previous work on Eavesdropping.

#### Prominent features

- [Front page](https://machinelistening.exposed/curriculum/)
- [Self-hosting Gitea instance](http://git.metadada.xyz/machinelistening/curriculum)
- [Embedded video/audio](https://machinelistening.exposed/topic/against-the-coming-world-of-listening-machines/) — Audio hyperlinks integrate a player with a nifty progress bar running over the hyperlinks.

DEVELOPER'S NOTE: Machine Listening, A Curriculum is a very early Sandpoints project, so it is not benefitting from some of its core features. The Machine Listening team did not implement print to PDF nor did it fully use the possiblilities of interlinking the publication structure. A lot of the links are leading to source Markdown files on the project's Gitea repo instead to their rendered versions on the website. Also, now there is a backlinks support feature indicating where a page is `Mentioned in`. Things like that. Still, very impressive work.

<br>

### Pirate Care Syllabus

#### About Pirate Care

> Pirate Care is a research process - primarily based in the transnational European space - that maps the increasingly present forms of activism at the intersection of “care” and “piracy”, which in new and interesting ways are trying to intervene in one of the most important challenges of our time, that is, the "crisis of care" in all its multiple and interconnected dimensions.

> Pirate Care team has been collaborating with practitioners of pirate care to document their situated knowledges of care activism and to instigate collective learning processes from these knowledges in a number of offline gatherings. To this end, in 2019 they have facilitated a collective writing process that involved over 20 activists, scholars and artists, producing a Pirate Care Syllabus. The aim of the Syllabus is to help mobilise new generations of activists for care-oriented struggles and, indeed, in the COVID-19 pandemic it proved to be a valuable resource for care organising.

DEVELOPER'S NOTE: Pirate Care custom Hugo theme was used as a prototype for Sandpoints. The current Sandpoints theme is substantially different and upgraded compared to the Pirate Care theme.

#### Prominent features

- [Front page](https://syllabus.pirate.care/)
- [PDF in Pirate Care's dedicated library](https://syllabus.pirate.care/library/BROWSE_LIBRARY.html#/book/7ea7d419-a6c0-40a4-98f1-05fbcb7442bf)
- [Pirate Care exhibition in Rijeka](https://drugo-more.hr/en/pirate-care/), [more photos](https://photos.app.goo.gl/ryqJzBNQh5VicXT39) — NOTE: All printouts for the exhibition were created "live" by using Chrome's Dev tools and printing directly to PDF.

## Bibliography

- ![](bib:debb6d78-1906-45bb-9d49-1915957bb2d5)
- ![](bib:02393f33-5f90-4d11-81ac-8b7f4fb545bc)
- ![](bib:e3f3d418-3516-489e-bb1d-abcb3e4b568e)
- ![](bib:c09d1cc3-a271-41ef-8986-4074606103e7)
